/*-----copyright-----
 *     amy-studio - make development easier 
 *     web        : http://www.amy-studio.com
 *     taobao     : http://amy-studio.taobao.com
 *     qq(e_mail) : amystudio@qq.com
 *-----file info-----
 *     name       : rider_led.v
 *     author     : Yuphone Chang
 *     description: turn on LEDs like a rider
 *----- version -----
 *     created    : 7.19, 2010
 *     version    : 1.0
 *     description: original version
 *
 *     modified   : 
 *     version    : 
 *     description: 
 *-------------------
 */

module rider_led(
  input        CLOCK_50,                // global clock 
  input        Q_KEY,                   // asynchronous reset 
  output [8:1] LED                      // LED[1] ~ LED[8]
);    

//++++++++++++++++++++++++++++++++++++++
// generating gated clock to display LEDs begins  
//++++++++++++++++++++++++++++++++++++++
reg [23:0] cnt;                         // counting number

// counter 
always @ (posedge CLOCK_50, negedge Q_KEY)
  if (!Q_KEY)
    cnt <= 0;
  else
    cnt <= cnt + 1'b1;
  
wire led_clk = cnt[23];                 // Cycle = (2^24/50M = 0.3355)sec
//--------------------------------------
// generating gated clock to display LEDs ends 
//--------------------------------------


//++++++++++++++++++++++++++++++++++++++
// the part of rider_led begins  
//++++++++++++++++++++++++++++++++++++++
reg [8:1]  led_r;
reg        dir;                         // shifting direction flag

always @ (posedge led_clk, negedge Q_KEY)
  if (!Q_KEY)                           // reset to shift left.
    dir <= 1;                            
  else
    // Does the LED arrive at the boundary of each side?
    // Once it arrives, change its direction.
    if(led_r[2])                        // led_r == 8'b02
      dir <= 1;
    else if(led_r[7])                   // led_r == 8'h40 
      dir <= 0;

always @ (posedge led_clk, negedge Q_KEY)
  if (!Q_KEY)                           // reset to shift left.
    led_r <= 8'h01;          
  else
    // On the board, LED[1] is on the right, 
    // and LED[8] is on the left.
    // The LED sequence is the same to binary number. 
    
    // according to the dir flag, change the LED shifting direction
    if(dir) 
      led_r <= led_r << 1;              // shift left
    else    
      led_r <= led_r >> 1;              // shift right

// Send 1 to turn off, and 0 to turn on.
assign LED = ~led_r;
//--------------------------------------
// the part of rider_led ends  
//--------------------------------------

endmodule
