/*-----copyright-----
 *     amy-studio - make development easier 
 *     web        : http://www.amy-studio.com
 *     taobao     : http://amy-studio.taobao.com
 *     qq(e_mail) : amystudio@qq.com
 *-----file info-----
 *     name       : key_led.v
 *     author     : Yuphone Chang
 *     description: use KEY to control LEDs, without debounce
 *----- version -----
 *     created    : 7.19, 2010
 *     version    : 1.0
 *     description: original version
 *
 *     modified   : 
 *     version    : 
 *     description: 
 *-------------------
 */

module key_led
(
  input            CLOCK_50,            // global clock 
  input            Q_KEY,               // asynchronous reset
  input      [4:1] KEY,                 // when pressed, input 0; otherwise, input 1
  output reg [4:1] LED                  // Send 1 to turn off, and 0 to turn on
);

wire [4:1] key_val = KEY;

//++++++++++++++++++++++++++++++++++++++
// using KEY to control LEDs begins
//++++++++++++++++++++++++++++++++++++++
always @ (posedge CLOCK_50, negedge Q_KEY)
  if (!Q_KEY)
    LED <= 4'hF;                       // turn off all LEDs 
  else
    case (1'b0)      
      key_val[1] : LED[1] <= ~LED[1];
      key_val[2] : LED[2] <= ~LED[2];
      key_val[3] : LED[3] <= ~LED[3];
      key_val[4] : LED[4] <= ~LED[4];
      default    : LED    <=  LED   ;
    endcase 
//--------------------------------------
// using KEY to control LEDs ends
//--------------------------------------

endmodule
  